wizard Package
==============

:mod:`wizard` Package
---------------------

.. automodule:: camelot.view.wizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`backup` Module
--------------------

.. automodule:: camelot.view.wizard.backup
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`importwizard` Module
--------------------------

.. automodule:: camelot.view.wizard.importwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`merge_document` Module
----------------------------

.. automodule:: camelot.view.wizard.merge_document
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`new` Module
-----------------

.. automodule:: camelot.view.wizard.new
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`new_company` Module
-------------------------

.. automodule:: camelot.view.wizard.new_company
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`update_value` Module
--------------------------

.. automodule:: camelot.view.wizard.update_value
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    camelot.view.wizard.pages

